@@ -5,62 +5,9 @@ use strict;
 
 use 5.008;
 
-=head1 NAME
 
-HTML::Latemp::News - News Maintenance Module for Latemp (and possibly other
-web frameworks)
+our $VERSION = '0.1.9';
 
-=cut
-
-our $VERSION = '0.1.8';
-
-=head1 SYNOPSIS
-
-    #!/usr/bin/perl
-
-    use strict;
-    use warnings;
-
-    use MyManageNews;
-
-    my @news_items =
-    (
-        .
-        .
-        .
-        {
-            'title' => "Changes of 18-April-2005",
-            'id' => "changes-2005-04-18",
-            'description' => q{Around 18 April, 2005, Jane's Site has seen a
-                lot of changes. Click the link for details on them.},
-            'date' => "2005-04-18",
-            'author' => "Jane Smith",
-            'category' => "Jane's Site",
-        },
-        .
-        .
-        .
-    );
-
-    my $news_manager =
-        HTML::Latemp::News->new(
-            'news_items' => \@news_items,
-            'title' => "Better SCM News",
-            'link' => "http://janes-site.tld/",
-            'language' => "en-US",
-            'copyright' => "Copyright by Jane Smith, (c) 2005",
-            'webmaster' => "Jane Smith <jane@janes-site.tld>",
-            'managing_editor' => "Jane Smith <jane@janes-site.tld>",
-            'description' => "News of Jane's Site - a personal site of " .
-                "Jane Smith",
-        );
-
-    $news_manager->generate_rss_feed(
-        'output_filename' => "dest/rss.xml"
-    );
-
-    1;
-=cut
 
 package HTML::Latemp::News::Base;
 
@@ -161,89 +108,6 @@ sub initialize
     return 0;
 }
 
-=head1 DESCRIPTION
-
-This is a module that maintains news item for a web-site. It can generate
-an RSS feed, as well as a news page, and an HTML newsbox, all from the same
-data.
-
-=head1 FUNCTION
-
-=head2 HTML::Latemp::News->new(...)
-
-This is the constructor for the news manager. It accepts the following named
-parameters:
-
-=over 8
-
-=item 'news_items'
-
-This is a reference to a list of news_items. See below.
-
-=item 'title'
-
-The title of the RSS feed.
-
-=item 'link'
-
-The link to the homepage of the site.
-
-=item 'language'
-
-The language of the text.
-
-=item 'copyright'
-
-The copyright notice of the text.
-
-=item 'webmaster'
-
-The Webmaster.
-
-=item 'managing_editor'
-
-The managing editor.
-
-=item 'description'
-
-A description of the news feed as will be put in the RSS feed.
-
-=back
-
-=head3 Format of the news_items
-
-The news_items is a reference to an array, of which each element is a hash
-reference. The hash may contain the following keys:
-
-=over 8
-
-=item 'title'
-
-The title of the item.
-
-=item 'id'
-
-The ID of the item. This will also be used to calculate URLs.
-
-=item 'description'
-
-A text description explaining what the item is all about.
-
-=item 'author'
-
-The author of the item.
-
-=item 'date'
-
-A string representing the daet.
-
-=item 'category'
-
-The cateogry of the item.
-
-=back
-
-=cut
 
 sub add_item_to_rss_feed
 {
@@ -334,13 +198,6 @@ sub generate_rss_feed
     $rss_feed->save($filename);
 }
 
-=head2 $news_manager->generate_rss_feed('output_filename' => "rss.xml")
-
-This generates an RSS feed. It accepts two named arguments.
-C<'output_filename'> is the name of the RSS file to write to. C<'num_items'>
-is the number of items to include, which defaults to 10.
-
-=cut
 
 sub get_navmenu_items
 {
@@ -360,13 +217,6 @@ sub get_navmenu_items
     return \@ret;
 }
 
-=head2 $news_manager->get_navmenu_items('num_items' => 5)
-
-This generates navigation menu items for input to the navigation menu of
-L<HTML::Widgets::NavMenu>. It accepts a named argument C<'num_items'> which
-defaults to 10.
-
-=cut
 
 sub format_news_page_item
 {
@@ -401,12 +251,6 @@ sub get_news_page_entries
     return $html;
 }
 
-=head2 $news_manager->get_news_page_entries('num_items' => 5, 'base_url' => "news/")
-
-This generates HTML for the news page. 'base_url' points to a URL to be
-appended to each item's ID.
-
-=cut
 
 sub get_news_box_contents
 {
@@ -443,16 +287,174 @@ sub get_news_box
     return $html;
 }
 
-=head2 $news_manager->get_news_box('num_items' => 5)
-
-This generates an HTML news box with the recent headlines.
-
-=cut
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::Latemp::News - News Maintenance Module for Latemp (and possibly other
+web frameworks)
+
+=head1 VERSION
+
+version 0.1.9
+
+=head1 SYNOPSIS
+
+    #!/usr/bin/perl
+
+    use strict;
+    use warnings;
+
+    use MyManageNews;
+
+    my @news_items =
+    (
+        .
+        .
+        .
+        {
+            'title' => "Changes of 18-April-2005",
+            'id' => "changes-2005-04-18",
+            'description' => q{Around 18 April, 2005, Jane's Site has seen a
+                lot of changes. Click the link for details on them.},
+            'date' => "2005-04-18",
+            'author' => "Jane Smith",
+            'category' => "Jane's Site",
+        },
+        .
+        .
+        .
+    );
+
+    my $news_manager =
+        HTML::Latemp::News->new(
+            'news_items' => \@news_items,
+            'title' => "Better SCM News",
+            'link' => "http://janes-site.tld/",
+            'language' => "en-US",
+            'copyright' => "Copyright by Jane Smith, (c) 2005",
+            'webmaster' => "Jane Smith <jane@janes-site.tld>",
+            'managing_editor' => "Jane Smith <jane@janes-site.tld>",
+            'description' => "News of Jane's Site - a personal site of " .
+                "Jane Smith",
+        );
+
+    $news_manager->generate_rss_feed(
+        'output_filename' => "dest/rss.xml"
+    );
+
+    1;
+
+=head1 DESCRIPTION
+
+This is a module that maintains news item for a web-site. It can generate
+an RSS feed, as well as a news page, and an HTML newsbox, all from the same
+data.
+
+=head1 FUNCTION
+
+=head2 HTML::Latemp::News->new(...)
+
+This is the constructor for the news manager. It accepts the following named
+parameters:
+
+=over 8
+
+=item 'news_items'
+
+This is a reference to a list of news_items. See below.
+
+=item 'title'
+
+The title of the RSS feed.
+
+=item 'link'
+
+The link to the homepage of the site.
+
+=item 'language'
+
+The language of the text.
+
+=item 'copyright'
+
+The copyright notice of the text.
+
+=item 'webmaster'
+
+The Webmaster.
+
+=item 'managing_editor'
+
+The managing editor.
+
+=item 'description'
+
+A description of the news feed as will be put in the RSS feed.
+
+=back
+
+=head3 Format of the news_items
+
+The news_items is a reference to an array, of which each element is a hash
+reference. The hash may contain the following keys:
+
+=over 8
+
+=item 'title'
+
+The title of the item.
+
+=item 'id'
+
+The ID of the item. This will also be used to calculate URLs.
+
+=item 'description'
+
+A text description explaining what the item is all about.
+
+=item 'author'
+
+The author of the item.
+
+=item 'date'
+
+A string representing the daet.
+
+=item 'category'
+
+The cateogry of the item.
+
+=back
+
+=head2 $news_manager->generate_rss_feed('output_filename' => "rss.xml")
+
+This generates an RSS feed. It accepts two named arguments.
+C<'output_filename'> is the name of the RSS file to write to. C<'num_items'>
+is the number of items to include, which defaults to 10.
+
+=head2 $news_manager->get_navmenu_items('num_items' => 5)
+
+This generates navigation menu items for input to the navigation menu of
+L<HTML::Widgets::NavMenu>. It accepts a named argument C<'num_items'> which
+defaults to 10.
+
+=head2 $news_manager->get_news_page_entries('num_items' => 5, 'base_url' => "news/")
+
+This generates HTML for the news page. 'base_url' points to a URL to be
+appended to each item's ID.
+
+=head2 $news_manager->get_news_box('num_items' => 5)
+
+This generates an HTML news box with the recent headlines.
+
 =head1 AUTHOR
 
 Shlomi Fish, C<< <shlomif@iglu.org.il> >>
@@ -478,4 +480,141 @@ Copyright 2005 Shlomi Fish, All Rights Reserved.
 This program is free software; you can redistribute it and/or modify it
 under the terms of the MIT X11 license.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2005 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Latemp-News or by email to
+bug-html-latemp-news@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc HTML::Latemp::News
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/HTML-Latemp-News>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/HTML-Latemp-News>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Latemp-News>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/HTML-Latemp-News>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/HTML-Latemp-News>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/HTML-Latemp-News>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/HTML-Latemp-News>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/H/HTML-Latemp-News>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=HTML-Latemp-News>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=HTML::Latemp::News>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-html-latemp-news at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-News>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<http://bitbucket.org/shlomif/latemp>
+
+  hg clone ssh://hg@bitbucket.org/shlomif/latemp
+
 =cut
